.. currentmodule:: abjad.tools.pitchtools

instantiate_pitch_and_interval_test_collection
==============================================

.. autofunction:: instantiate_pitch_and_interval_test_collection
